Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(260)

Unified Diff: remoting/host/constants.h

Issue 10873050: [Chromoting] Hook up host talkgadget policy checks. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Move callback Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | remoting/host/constants.cc » ('j') | remoting/host/dns_blackhole_checker.h » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/constants.h
diff --git a/remoting/host/constants.h b/remoting/host/constants.h
index 54aa2280c657a5ec1fdc210838a88f1c20071179..be3c1a6e9afe51f19f61de334f08bd915d760551 100644
--- a/remoting/host/constants.h
+++ b/remoting/host/constants.h
@@ -9,10 +9,10 @@
namespace remoting {
// This is the default prefix that is prepended to ".talkgadget.google.com"
// to form the complete talkgadget domain name. Policy settings allow admins
// to change the prefix that is used.
-extern const char kDefaultTalkGadgetPrefix[];
+extern const char kDefaultHostTalkGadgetPrefix[];
Sergey Ulanov 2012/08/30 18:05:01 can we move it to dns_blackhole_checker.h? Then y
garykac 2012/08/31 18:28:23 Done. This is used by policy_watcher and dns_black
// Known host exit codes.
@@ -9,10 +9,10 @@
namespace remoting {
-// This is the default prefix that is prepended to ".talkgadget.google.com"
-// to form the complete talkgadget domain name. Policy settings allow admins
+// This is the default prefix that is prepended to the kTalkGadgetUrl to form
+// the complete talkgadget URL used by the host. Policy settings allow admins
// to change the prefix that is used.
// Please keep this enum in sync with:
« no previous file with comments | « no previous file | remoting/host/constants.cc » ('j') | remoting/host/dns_blackhole_checker.h » ('J')

Powered by Google App Engine
This is Rietveld 408576698